<div align="center">

<a href="https://v2.nonebot.dev/store">
  <img src="https://raw.githubusercontent.com/clovers-project/clovers.github.io/master/docs/icon.png" width="180" height="180" alt="clovers">
</a>

# clovers

_✨ 高度自定义的聊天平台 Python 异步机器人指令-响应插件框架 ✨_

<img src="https://img.shields.io/badge/python-3.12+-blue.svg" alt="python">
<a href="./LICENSE">
  <img src="https://img.shields.io/github/license/KarisAya/clovers.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/clovers">
  <img src="https://img.shields.io/pypi/v/clovers.svg" alt="pypi">
</a>
<a href="https://pypi.python.org/pypi/clovers">
  <img src="https://img.shields.io/pypi/dm/clovers" alt="pypi download">
</a>

[使用文档](https://clovers-project.github.io/)

</div>

# 联系

如有建议，bug 反馈等可以加群

机器人 bug 研究中心（闲聊群） 744751179

永恒之城（测试群） 724024810

![群号](https://raw.githubusercontent.com/clovers-project/clovers/master/%E9%99%84%E4%BB%B6/qrcode_1676538742221.jpg)

# 鸣谢

- [nonebot2](https://github.com/nonebot/nonebot2) 跨平台 Python 异步聊天机器人框架 ~~需求都是基于这个写的~~
